@@ -87,7 +87,7 @@ class File(BaseNode):
             response = api.post(
                 url=f"{api.url}/{self.slug}/",
                 data=self._to_json(),
-                valid_codes=[201, 400],
+                valid_codes=[200, 201, 400],
             )
 
             # Check if a unique error was returned
