@@ -1,14 +1,16 @@
 import json
-
-import requests
 from logging import getLogger
+
 import globus_sdk
+import requests
 from globus_sdk.scopes import ScopeBuilder
 
 from cript.data_model.nodes.base_node import BaseNode
-from cript.storage_clients.exceptions import FileUploadError
-from cript.storage_clients.exceptions import FileDownloadError
-
+from cript.storage_clients.exceptions import (
+    FileDownloadError,
+    FileUploadError,
+    InvalidAuthCode,
+)
 
 logger = getLogger(__name__)
 
@@ -154,7 +156,11 @@ class GlobusClient:
             auth_code = input("Enter the code here: ").strip()
 
         # Get tokens
-        token_response = self.auth_client.oauth2_exchange_code_for_tokens(auth_code)
+        try:
+            token_response = self.auth_client.oauth2_exchange_code_for_tokens(auth_code)
+        except globus_sdk.services.auth.errors.AuthAPIError as error:
+            raise InvalidAuthCode from error
+
         auth_data = token_response.by_resource_server["auth.globus.org"]
         transfer_data = token_response.by_resource_server["transfer.api.globus.org"]
         https_transfer_data = token_response.by_resource_server[self.endpoint_id]
